import React, { Component } from 'react';

/**
 * Error Boundary component to catch errors in child components
 * and display a fallback UI instead of crashing the whole app
 */
class ErrorBoundary extends Component {
    constructor(props) {
        super(props);
        this.state = { hasError: false, error: null };
    }

    static getDerivedStateFromError(error) {
        // Update state so the next render will show the fallback UI
        return { hasError: true, error };
    }

    componentDidCatch(error, errorInfo) {
        // You can log the error to an error reporting service
        console.error('Error caught by ErrorBoundary:', error);
        console.error('Component stack:', errorInfo.componentStack);
    }

    render() {
        const { children, fallback } = this.props;

        if (this.state.hasError) {
            // You can render any custom fallback UI
            if (typeof fallback === 'function') {
                return fallback(this.state.error);
            }

            return (
                fallback || (
                    <div className='p-3 border rounded bg-light'>
                        <p className='text-danger mb-1'>Error rendering content</p>
                        <small className='text-muted'>The content couldn't be displayed properly.</small>
                    </div>
                )
            );
        }

        return children;
    }
}

export default ErrorBoundary;
