import React, { useRef, useState, useEffect } from 'react';
import { useDispatch } from 'react-redux';
import { uploadDocument, getKnowledgeBaseDocuments } from '../../../../store/knowledgeBase/knowledgeBase.thunks';

/**
 * 文件上传模态框组件
 */
const FileUploadModal = ({ show, knowledgeBaseId, onClose }) => {
    const dispatch = useDispatch();
    const fileInputRef = useRef(null);
    const modalRef = useRef(null);
    const [selectedFiles, setSelectedFiles] = useState([]);
    const [isUploading, setIsUploading] = useState(false);
    const [fileError, setFileError] = useState('');
    const [uploadResults, setUploadResults] = useState(null);

    // 处理上传区域点击事件
    const handleUploadAreaClick = () => {
        fileInputRef.current?.click();
    };

    // 处理拖拽事件
    const handleDragOver = (e) => {
        e.preventDefault();
        e.stopPropagation();
    };

    const handleDrop = (e) => {
        e.preventDefault();
        e.stopPropagation();

        if (e.dataTransfer.files && e.dataTransfer.files.length > 0) {
            handleFilesSelected(e.dataTransfer.files);
        }
    };

    const handleFileChange = (e) => {
        if (e.target.files && e.target.files.length > 0) {
            handleFilesSelected(e.target.files);
        }
    };

    const handleFilesSelected = (files) => {
        setFileError('');
        // 将FileList转为数组
        const filesArray = Array.from(files);
        setSelectedFiles((prev) => [...prev, ...filesArray]);
    };

    const removeFile = (index) => {
        setSelectedFiles((prev) => prev.filter((_, i) => i !== index));
    };

    const resetFileInput = () => {
        setSelectedFiles([]);
        setFileError('');
        setUploadResults(null);
        if (fileInputRef.current) {
            fileInputRef.current.value = '';
        }
    };

    const handleUpload = async () => {
        if (selectedFiles.length === 0) {
            setFileError('请至少选择一个要上传的文件');
            return;
        }

        setIsUploading(true);
        setUploadResults(null);

        try {
            const result = await dispatch(
                uploadDocument({
                    knowledge_base_id: knowledgeBaseId,
                    files: selectedFiles,
                })
            ).unwrap();

            // 成功上传后刷新文档列表
            dispatch(getKnowledgeBaseDocuments({ knowledge_base_id: knowledgeBaseId }));

            // 显示上传结果
            setUploadResults(result);

            // 如果没有失败的文件，就在3秒后自动关闭模态窗
            if (result.failed_count === 0) {
                setTimeout(() => {
                    handleClose();
                }, 3000);
            }
        } catch (error) {
            console.error('Upload failed:', error);
            setFileError('文件上传失败: ' + (error?.message || '未知错误'));
        } finally {
            setIsUploading(false);
        }
    };

    const handleClose = () => {
        // 只有在非上传状态才允许关闭
        if (!isUploading) {
            resetFileInput();
            onClose();
        }
    };

    // 清理函数
    useEffect(() => {
        return () => {
            // 确保在组件卸载时清理所有引用
            if (fileInputRef.current) {
                fileInputRef.current.value = '';
            }
            if (modalRef.current) {
                modalRef.current = null;
            }
        };
    }, []);

    if (!show) return null;

    return (
        <div
            ref={modalRef}
            className='modal-backdrop'
            style={{
                position: 'fixed',
                top: 0,
                left: 0,
                right: 0,
                bottom: 0,
                backgroundColor: 'rgba(0, 0, 0, 0.5)',
                display: 'flex',
                alignItems: 'center',
                justifyContent: 'center',
                zIndex: 1050,
            }}
        >
            <div
                className='modal-content bg-white rounded shadow'
                style={{
                    width: '600px',
                    maxWidth: '90%',
                    padding: '20px',
                    maxHeight: '90vh',
                    overflowY: 'auto',
                }}
            >
                <div className='modal-header d-flex justify-content-between align-items-center mb-3'>
                    <h5 className='modal-title m-0'>上传文档</h5>
                    <button
                        type='button'
                        className='btn-close'
                        onClick={handleClose}
                        disabled={isUploading}
                        aria-label='Close'
                    ></button>
                </div>
                <div className='modal-body'>
                    <div
                        className={`mb-3 p-4 border rounded text-center ${
                            fileError ? 'border-danger' : 'border-dashed'
                        }`}
                        style={{ cursor: isUploading ? 'not-allowed' : 'pointer' }}
                        onClick={!isUploading ? handleUploadAreaClick : undefined}
                        onDrop={!isUploading ? handleDrop : undefined}
                        onDragOver={handleDragOver}
                    >
                        <input
                            type='file'
                            ref={fileInputRef}
                            className='d-none'
                            onChange={handleFileChange}
                            accept='.pdf,.doc,.docx,.txt,.md,.csv,.xlsx,.xls'
                            disabled={isUploading}
                            multiple
                        />
                        <div>
                            <p className='mb-1'>点击或拖拽文件到此处上传</p>
                            <p className='text-muted small mb-0'>支持 PDF, Word, Excel, TXT, Markdown, CSV 等格式</p>
                        </div>
                        {fileError && <div className='text-danger mt-2'>{fileError}</div>}
                    </div>

                    {/* 选择的文件列表 */}
                    {selectedFiles.length > 0 && (
                        <div className='mb-3'>
                            <p className='fw-bold mb-2'>已选择 {selectedFiles.length} 个文件：</p>
                            <ul className='list-group'>
                                {selectedFiles.map((file, index) => (
                                    <li
                                        key={index}
                                        className='list-group-item d-flex justify-content-between align-items-center'
                                    >
                                        <div
                                            className='d-flex align-items-center'
                                            style={{ maxWidth: 'calc(100% - 70px)' }}
                                        >
                                            <div className='text-truncate'>{file.name}</div>
                                            <div className='text-nowrap ms-2 text-muted' style={{ flexShrink: 0 }}>
                                                ({(file.size / 1024).toFixed(0)} KB)
                                            </div>
                                        </div>
                                        {!isUploading && (
                                            <button
                                                className='btn btn-sm btn-outline-danger'
                                                onClick={() => removeFile(index)}
                                                style={{ minWidth: '60px' }}
                                            >
                                                移除
                                            </button>
                                        )}
                                    </li>
                                ))}
                            </ul>
                        </div>
                    )}

                    {/* 上传结果显示 */}
                    {uploadResults && (
                        <div className='mt-3 border rounded p-3'>
                            <h6 className='mb-2'>上传结果</h6>
                            <p className='mb-2'>
                                总文件: {uploadResults.total_files}, 成功: {uploadResults.uploaded_count}, 失败:{' '}
                                {uploadResults.failed_count}
                            </p>

                            {uploadResults.documents && uploadResults.documents.length > 0 && (
                                <>
                                    <p className='mb-1 fw-bold text-success'>上传成功:</p>
                                    <ul className='list-group mb-2'>
                                        {uploadResults.documents.map((doc) => (
                                            <li key={doc.id} className='list-group-item py-2 d-flex align-items-center'>
                                                <span className='badge bg-success me-2'>✓</span>
                                                <span className='text-truncate'>{doc.name}</span>
                                            </li>
                                        ))}
                                    </ul>
                                </>
                            )}

                            {uploadResults.failed_documents && uploadResults.failed_documents.length > 0 && (
                                <>
                                    <p className='mb-1 fw-bold text-danger'>上传失败:</p>
                                    <ul className='list-group'>
                                        {uploadResults.failed_documents.map((doc, index) => (
                                            <li key={index} className='list-group-item py-2 d-flex align-items-center'>
                                                <span className='badge bg-danger me-2'>✗</span>
                                                <div className='text-truncate'>
                                                    {doc.name}
                                                    {doc.reason && (
                                                        <small className='ms-2 text-danger'>({doc.reason})</small>
                                                    )}
                                                </div>
                                            </li>
                                        ))}
                                    </ul>
                                </>
                            )}
                        </div>
                    )}
                </div>
                <div className='modal-footer gap-2'>
                    <button type='button' className='btn btn-secondary' onClick={handleClose} disabled={isUploading}>
                        关闭
                    </button>
                    <button
                        type='button'
                        className='btn btn-dark'
                        onClick={handleUpload}
                        disabled={selectedFiles.length === 0 || isUploading}
                    >
                        {isUploading ? (
                            <>
                                <span
                                    className='spinner-border spinner-border-sm me-2'
                                    role='status'
                                    aria-hidden='true'
                                ></span>
                                上传中...
                            </>
                        ) : (
                            `上传文档${selectedFiles.length > 0 ? ` (${selectedFiles.length})` : ''}`
                        )}
                    </button>
                </div>
            </div>
        </div>
    );
};

export default FileUploadModal;
